#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages
import os
import subprocess

name = 'pyaardvark'
version_py = os.path.join(os.path.dirname(__file__), name, 'version.py')
try:
    version = subprocess.check_output(
            ['git', 'describe', '--tags', '--always', '--dirty'],
            stderr=subprocess.STDOUT).rstrip()
    with open(version_py, 'w') as f:
        f.write('# This file was autogenerated by setup.py\n')
        f.write('__version__ = \'%s\'\n' % (version,))
except (IOError, subprocess.CalledProcessError) as e:
    try:
        with open(version_py, 'r') as f:
            d = dict()
            exec(f, d)
            version = d['__version__']
    except IOError:
        version = 'unknown'

with open('README.rst') as f:
    readme = f.read()

setup(name = name,
        version = version,
        description = 'Total Phase Aardvark library',
        long_description = readme,
        author = 'Michael Walle',
        author_email = 'michael.walle@kontron.com',
        packages = find_packages(),
        url = 'http://github.com/kontron/python-aardvark',
        license = 'LGPLv2+',
        classifiers = [
            'Development Status :: 3 - Alpha',
            'Environment :: Console',
            'License :: OSI Approved :: GNU Lesser General Public License v2 or later (LGPLv2+)',
            'Natural Language :: English',
            'Operating System :: OS Independent',
            'Programming Language :: Python :: 2',
            'Programming Language :: Python :: 2.7',
            'Topic :: Software Development :: Libraries :: Python Modules',
        ],
        entry_points = {
            'console_scripts': [
                'aardvark = pyaardvark.cli_tool:main',
            ]
        },
        test_suite = 'tests',
        include_package_data = True,
)
